%Test the speeds of the various measurement methods

%Load an image
img=imread('testdata/i3.jpg');
img=mean(img,3);

%Generate templates that are 
%[10,15,20,30,50].^2 in size
kTemplateSize = [15 20 30 40 50 60];
for cTemplate = 1:length(kTemplateSize)
  cTemplateSize = kTemplateSize( [cTemplate cTemplate] );
  tmp{cTemplate} = mexMIx( img, [size(img)/2], cTemplateSize );
end

%Set up the 17 kinds of measurement method
kParameters = [
    1  1  1  2  2  2 31 31 31 40 41 42 43 50 51 52 53
    0  1  3  0  1  3  0  1  3  0  1  2  3  0  1  2  3
   16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16
    1  1  1  1  1  1  1  1  1  1  1  1  1  1  1  1  1];

%Set up 10000 warp positions
[x y] = meshgrid([1:1:10]);
warps = [450+x(:) 600+y(:)]';

%Time the measurements for evaluating Y and DY/DX
evalYTimes = zeros(5,17);
evalDTimes = zeros(5,17);
for cTemplate = 1:5
  for cParameter = 1:17
    tic;
    y = mexMImsr(tmp{cTemplate},img,warps,kParameters(:,cParameter));
    evalYTimes(cTemplate,cParameter) = toc;
    tic;
    [y,dy] = mexMImsr(tmp{cTemplate},img,warps,kParameters(:,cParameter));
    evalDTimes(cTemplate,cParameter) = toc;    
  end
end

%Plot the results
xseries = repmat([1:17],5,1);
ydivision = repmat( kTemplateSize'.^2, 1, 17 )*100/1e+6;
myxlabels = {'SSD NNI','SSD BLI','SSD BCI',...
             'NC NNI','NC BLI','NC BCI',...
             'I_{std} NNI','I_{std} BLI','I_{std} BCI',...
             'I_{pve} NNI','I_{pve} BLI','I_{pve} BLI','I_{pve} BCI',...
             'I_{ipz} NNI','I_{ipz} BLI','I_{ipz} BLI','I_{ipz} BCI'};

addpath('~/zPers/dev/zuseful');
figure(1);
myFig = subplot(1,2,1); 
plot(evalYTimes./ydivision,xseries,'k-x');
xlabel('(a) Cost to evaluate Measure ({\mu}s / pixel)');
set(gca,'YTick',[1:17]);
set(gca,'YTickLabel',myxlabels);
set(gca,'YTickMode','manual');
set(gca,'YAxisLocation','Right');
axis([0 4 0 18 ]);
%stdLabel( myFig, '(a)', 0.5);

myFig = subplot(1,2,2); 
plot(evalDTimes./ydivision,xseries,'k-x');
xlabel('(b) Cost to evaluate Measure and Jacobian ({\mu}s / pixel)');
set(gca,'YTick',[1:17]);
set(gca,'YTickLabel',myxlabels);
set(gca,'YTickMode','manual');
set(gca,'YAxisLocation','Right');
axis([0 4 0 18 ]);
%set(gca,'YTickLabel',repmat('',17,1));
%stdLabel( myFig, '(b)', 0.5);

stdFontSz(1,16);

%Set the paper size
set(gcf,'PaperUnits','centimeters');
set(gcf,'PaperPosition',[0 0 32 12]);
set(gcf,'PaperSize',[32 12]);
print('-depsc2','ComputationalCost.eps');
close(1);
